#ifdef __AVR_ATtiny85__
  #include <TinyWireM.h>
  #define Wire TinyWireM
#else
  #include <Wire.h>
#endif


#ifdef __AVR
  #include <avr/pgmspace.h>
#elif defined(ESP8266)
  #include <pgmspace.h>
#endif
#include "CLab_MCP4631.h"


///////////////////////////////////////////////////////////////////////////////

/**
 * Initializes the MCP23017 given its HW selected address, see datasheet for Address selection.
   Could be generalized to allow passing pin numbers to wire, I suppose
 */
void CLab_MCP4631::begin(uint8_t addr) {
	if (addr > 0x2f) {
		addr = 0x28;
	}
	i2caddr = addr;
	Wire.begin();

	// set defaults?  general call is enabled at start though we don't use it
	// TCON comes up in a usable state; if others are using general call, there'll be problems
}

///////////////////////////////////////////////////////////////////////////////
/* write a value into wiper 0 or 1
 lower 7 bits are valid, we and-off the top bit of a char, top value is 127 
 where the W pin is connected to pin A (B might ge grounded in normal pot use).
 Only the bottom bit of which is used - 0 is pot 0, 1 is 1
 */ 
void CLab_MCP4631::writeWiper(uint8_t which, uint8_t pos)
{
	which &= 0x01; // prevent user fumbles
	if (pos > 0x80) pos = 0x80; // microchip is just wierd here - 129 steps
    Wire.beginTransmission(i2caddr);
    Wire.write(which);
    Wire.write(pos);
    Wire.endTransmission(i2caddr);	
}